from pathlib import Path

class ResourceManager:
    """
    A class to manage assets in the resources folder.
    Works locally and if installed.
    """
    def __init__(self, asset_folder: str):
        self.asset_dir = self._get_resource_path() / asset_folder
        
    def list(self):
        return [p.name for p in self.asset_dir.iterdir()]
    
    def get(self, asset_name: str):
        with open(self.asset_dir / asset_name, 'r') as f:
            return f.read()
        
    def update(self, asset_name: str, content: str):
        with open(self.asset_dir / asset_name, 'w') as f:
            f.write(content)

    def create(self, asset_name: str, content: str):
        if (self.asset_dir / asset_name).exists():
            raise FileExistsError(f"File {asset_name} already exists")
        with open(self.asset_dir / asset_name, 'w') as f:
            f.write(content)
    
    def delete(self, asset_name: str):
        (self.asset_dir / asset_name).unlink()
        
    def _get_resource_path(self) -> Path:
        base_dir = Path(__file__).parent.parent
        resource_dir = base_dir / "resources"
        return resource_dir



import _to_parent
from libraries.subnet_scan import SubnetScanner, cleanup_old_jobs
import subprocess


def copy2clip(txt):
    cmd='echo '+txt.strip()+'|clip'
    return subprocess.check_call(cmd, shell=True)
def main():

    # Create a SubnetScanner instance and start scanning
    scanner = SubnetScanner('10.0.0.0/20', 'large', 1)
    scanner.scan_subnet_threaded()
    copy2clip(scanner.uid)
    scanner.debug_active_scan()
    cleanup_old_jobs()
def main2():
    scanner = SubnetScanner('10.0.0.0/26', 'small', .5)
    print(scanner.uid)
    scanner.scan_subnet()

def main3():
    uid = SubnetScanner.scan_subnet_standalone('10.0.10.0/24','small', 1)
    copy2clip(uid)
    print(uid)
#main()
#main2()
main3()




class SubnetTooLargeError(Exception):
    """Custom exception raised when the subnet size exceeds the allowed limit."""
    def __init__(self, subnet):
        self.subnet = subnet
        super().__init__(f"Subnet {subnet} exceeds the limit of IP addresses.")
